aboutsummaryrefslogtreecommitdiffstats
path: root/src/java/com/jogamp/common/util/UnsafeUtil.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/java/com/jogamp/common/util/UnsafeUtil.java')
-rw-r--r--src/java/com/jogamp/common/util/UnsafeUtil.java5
1 files changed, 2 insertions, 3 deletions
diff --git a/src/java/com/jogamp/common/util/UnsafeUtil.java b/src/java/com/jogamp/common/util/UnsafeUtil.java
index 6fde3fa..d1b2dd8 100644
--- a/src/java/com/jogamp/common/util/UnsafeUtil.java
+++ b/src/java/com/jogamp/common/util/UnsafeUtil.java
@@ -31,7 +31,6 @@ import java.lang.reflect.Field;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.nio.ByteBuffer;
-import java.security.AccessController;
import java.security.PrivilegedAction;
import com.jogamp.common.ExceptionUtils;
@@ -73,7 +72,7 @@ public class UnsafeUtil {
final Class<?>[] _illegalAccessLoggerClass = { null };
final Long[] _loggerOffset = { null };
- AccessController.doPrivileged(new PrivilegedAction<Object>() {
+ SecurityUtil.doPrivileged(new PrivilegedAction<Object>() {
@Override
public Object run() {
Class<?> unsafeClass = null;
@@ -172,7 +171,7 @@ public class UnsafeUtil {
/**
* Issue the given user {@code action} while {@code jdk.internal.module.IllegalAcessLogger}'s {@code logger} has been temporarily disabled.
* <p>
* The caller shall place this call into their own {@link AccessController#doPrivileged(PrivilegedAction)} block.
* </p>
* <p>
* In case the runtime is not {@link PlatformPropsImpl#JAVA_9} or the logger is not accessible or disabling caused an exception,
@@ -172,7 +171,7 @@ public class UnsafeUtil {
* Issue the given user {@code action} while {@code jdk.internal.module.IllegalAcessLogger}'s {@code logger} has been temporarily disabled.
* <p>
- * The caller shall place this call into their own {@link AccessController#doPrivileged(PrivilegedAction)} block.
+ * The caller shall place this call into their own {@link SecurityUtil#doPrivileged(PrivilegedAction)} block.
* </p>
* <p>